/* FILE: avftovio.cc                 -*-Mode: c++-*-
 *
 * Program to try to convert from Any (known) Vector Field file
 * to a vio vector field file format.
 *
 */

#include <stdio.h>
#include "machine.h"
#include "misc.h"
#include "tclcmds.h"
#include "template.h"
#include "vector.h"
#include "vecfile.h"

void Usage(void)
{
  fprintf(stderr,"Usage: avftovio infile >outfile\n");
  exit(1);
}

int main(int argc,char **argv)
{
  char *inname;
  Mesh *mesh;

  Omf_InitLight(argv[0]);

  if(argc!=2) Usage();
  inname=argv[1];

  // Fill mesh from input file
  VectorFieldFileInput *vffreader
    = VectorFieldFileInput::NewReader(inname);
  if(vffreader==NULL) { // Unknown file type or other error
    fprintf(stderr,"ERROR detected processing file %s\n",inname);
    exit(1);
  }
  else { // Reader found for inname
    mesh=vffreader->NewMesh();
    delete vffreader;
    if(mesh==NULL) {
      fprintf(stderr,"ERROR detected while reading file %s\n",inname);
      exit(2);
    }
  }

  // Write vio file to stdout
  VioFileOutput vfo;
  vfo.WriteMesh(mesh,stdout,NULL);

  // That's all folks!
  fflush(stdout);
  return 0;
}
