#!/bin/sh
# This comment continues on in Tcl, but not in sh \
exec wish "$0" ${1+"$@"}
#
# If the above exec doesn't work, replace ${1+"$@"} with "$@"
# The syntax ${1+"$@"} means: if $1 (positional parameter #1)
# is set, then substitute "$@" (all parameters as separate words),
# if $1 is not set (no command line arguments), then substitute
# nothing.  Bash makes no substitution for "$@" if $1 is not set,
# so these are equivalent under bash.  Apparently there is some
# danger that a shell may substitute "" for "$@" if $1 is not set,
# but I don't know which shells do that.

if {$argc<2 || [string match "-h*" [lindex $argv 0]]} {
    puts "Usage: cvtpic output_type file1 \[file2 ...\]"
    exit
}
set type [lindex $argv 0]
foreach inname [lrange $argv 1 end] {
    if {![file readable $inname]} {
	puts "Unable to open input file $inname; Skipping..." ; flush stdout
    } else {
	puts -nonewline "Reading input file $inname..." ; flush stdout
	if {[catch {set pic [image create photo -file $inname]} errmsg]} {
	    puts "ERROR: $errmsg" ; flush stdout
	    continue
	}
	set outname [file rootname $inname].$type
	if {[file exists $outname]} {
	    set basename $outname
	    set outname {}
	    for {set i 1} {$i<100} {incr i} {
		set testname ${basename}.$i
		if {![file exists $testname]} {
		    set outname $testname
		    break
		}
	    }
	}
	if {[string match {} $outname]} {
	    puts "Unable to generate unique output name.  Output skipped"
	    flush stdout
	} else {
	    if {[catch {$pic write $outname -format $type} errmsg]} {
		puts "ERROR: $errmsg"
	    } else {
		puts "Output written to file $outname"
	    }
	    flush stdout
	}
    }
}
exit
