#!/bin/sh
# This comment continues on in Tcl, but not in sh \
exec wish "$0" ${1+"$@"}
#
# usage: filesource.tcl <mif-file>

if {[llength $argv] != 1} {
    error "usage: filesource.tcl <mif-file>"
}

set mmpe(foo) [lindex $argv 0]
set mmpe(foohome) [string trimright [file dirname $mmpe(foo)] ./]
set mmpe(foohome) [file join [pwd] $mmpe(foohome)]
set importedFilename [file join $mmpe(foohome) [file tail $mmpe(foo)]]

# Directory knowledge
set mmpe(dirrel) [string trimright [file dirname [info script]] ./]
set mmpe(dirabs) [file join [pwd] $mmpe(dirrel)]
set mmpe(libdir) [file join [file dirname $mmpe(dirabs)] oommf library]

# Make sure oommf.tcl is sourced
source [file join $mmpe(libdir) oommf0.0 oommf.tcl]

#**************************************************************************#  
# Library support
lappend auto_path $mmpe(libdir)
package require em
package require oommf
package require net

#**************************************************************************#  
#top level window
label .l -text "I export the file: $importedFilename"
label .l2 -text ""
button .quit -text "Quit" -command { Die } 
pack .l -side top -expand 1
pack .l2 -side top -expand 1
pack .quit -side bottom -expand 1

proc Die {} {
    global protocol
    if {[info exists protocol]} {
	$protocol delete; after 2000 exit
    }
}
bind . <Destroy> "+Die"
wm title . FileSource<[pid]>

#**************************************************************************#  
# networking
set protocol [net_protocol new -name "OOMMF ProbEd protocol 0.0"]
$protocol AddMessage start HasGui {} {
    return [list start [list 0 0]]
}
$protocol AddMessage start GetProbDescFile {} {
    global importedFilename
    set exportedFilename [OMF_TempName]
    .l2 configure -text "Passing via temporary: $exportedFilename"
    after 5000 {.l2 configure -text ""}
    OMF_File copy $importedFilename $exportedFilename
    return [list start [list 0 $exportedFilename]]
}
set server [net_server new -protocol $protocol \
        -alias FileSource -log em_nop]
$server Start 0

