/* FILE: mmsolve.cc                 -*-Mode: c++-*-
 *
 * Skeleton for mmsolve interpreter shell application.
 *
 */

#include <tcl.h>	/* TCL_OK, ... */
#include <string.h>	/* strcmp */
#include "misc.h"
#include "mmsolve.h"	/* Mmsolve_Init, Mmsolve_SafeInit */
/* End includes */     

//#define USE_TK   // Select between Tcl and Tk interpreter

int Tcl_AppInit(Tcl_Interp *interp)
{
    if (Tcl_Init(interp) == TCL_ERROR) {
      return TCL_ERROR;
    }

    if (Oommf_Init(interp) == TCL_ERROR) {
       return TCL_ERROR;
    }
    if (Mmsolve_Init(interp) == TCL_ERROR) {
       return TCL_ERROR;
    }
    return TCL_OK;
}

int Tk_AppInit(Tcl_Interp *interp)
{
    if (Tcl_Init(interp) == TCL_ERROR) {
      return TCL_ERROR;
    }

    if (Tk_Init(interp) == TCL_ERROR) { return TCL_ERROR; }
    Tcl_StaticPackage(interp,AutoBuf("Tk"), Tk_Init,
		      (Tcl_PackageInitProc *) NULL);

    if (Oommf_Init(interp) == TCL_ERROR) {
       return TCL_ERROR;
    }
    if (Mmsolve_Init(interp) == TCL_ERROR) {
       return TCL_ERROR;
    }
    return TCL_OK;
}

// Utility routine that removes argument "remove_index" from
// the argument list by translating all arguments after it down
// one spot and decrementing argc.
static void remove_arg(int &argc,char **argv,int remove_index)
{
  if(remove_index<0 || remove_index>=argc) return;
  for(int j=remove_index+1;j<argc;j++) {
    argv[j-1]=argv[j];
  }
  argc--;
}

int main(int argc, char **argv)
{
  int use_tk=1;  // Default is to use tk.

  // Search for the options "-notk" and "-tk"; if found, set
  // use_tk appropriately.  A "--" can be used to end further
  // option processing (arguments are processed left to right).
  for(int i=1;i<argc;i++) {
    if(strcmp("--",argv[i])==0) break;  // End option list
    if(strcmp("-notk",argv[i])==0) {
      use_tk=0; remove_arg(argc,argv,i);
    }
    else if(strcmp("-tk",argv[i])==0) {
      use_tk=1; remove_arg(argc,argv,i);
    }
  }

  if(use_tk)
    Tk_Main(argc, argv, Tk_AppInit);
  else
    Tcl_Main(argc, argv, Tcl_AppInit);
  return 0;
}


